Package 'annotables'

Title: Ensembl Annotation Tables
Description: Provides tables for converting and annotating Ensembl Gene IDs.
Authors: Stephen Turner [aut, cre], Michael J. Steinbaugh [ctb], Aaron Wolen [ctb]
Maintainer: Stephen Turner <[email protected]>
License: GPL-3
Version: 0.2.0
Built: 2026-06-08 08:03:06 UTC
Source: https://github.com/stephenturner/annotables

Help Index


annotables

Description

Provides tables for converting and annotating Ensembl Gene IDs.

Author(s)

Maintainer: Stephen Turner [email protected]

Other contributors:

See Also

Useful links:


Fruitfly annotation data

Description

Fruitfly (Drosophila melanogaster) annotations based on genome assembly BDGP6 from Ensembl.

Usage

bdgp6

Format

An object of class tbl_df (inherits from tbl, data.frame) with 26383 rows and 9 columns.

Details

Variables:

  • ensgene

  • entrez

  • symbol

  • chr

  • start

  • end

  • strand

  • biotype

  • description

http://ensembl.org/drosophila_melanogaster

Examples

head(bdgp6)

Fruitfly transcripts to genes

Description

Lookup table for converting Fruitfly (Drosophila melanogaster) Ensembl transcript IDs to gene IDs based on genome assembly BDGP6 from Ensembl.

Usage

bdgp6_tx2gene

Format

An object of class tbl_df (inherits from tbl, data.frame) with 41600 rows and 2 columns.

Details

Variables:

  • enstxp

  • ensgene

http://ensembl.org/drosophila_melanogaster

Examples

head(bdgp6_tx2gene)

Dog gene annotation table

Description

Gene annotation table for Canis lupus familiaris (dog) from Ensembl.

Usage

cfamiliaris

Format

A data frame with gene annotation columns.

Details

Variables:

  • ensgene

  • entrez

  • symbol

  • chr

  • start

  • end

  • strand

  • biotype

  • description

Ensembl

http://ensembl.org/canis_lupus familiaris

Examples

head(cfamiliaris)

Dog transcript-to-gene table

Description

Transcript-to-gene mapping for Canis lupus familiaris (dog) from Ensembl.

Usage

cfamiliaris_tx2gene

Format

A data frame with transcript and gene columns.

Ensembl


Zebrafish gene annotation table

Description

Gene annotation table for Danio rerio (zebrafish) from Ensembl.

Usage

drerio

Format

A data frame with gene annotation columns.

Details

Variables:

  • ensgene

  • entrez

  • symbol

  • chr

  • start

  • end

  • strand

  • biotype

  • description

Ensembl

http://ensembl.org/danio_rerio

Examples

head(drerio)

Zebrafish transcript-to-gene table

Description

Transcript-to-gene mapping for Danio rerio (zebrafish) from Ensembl.

Usage

drerio_tx2gene

Format

A data frame with transcript and gene columns.

Ensembl


Ensembl version used for build

Description

Ensembl version used for build

Usage

ensembl_version

Format

An object of class character of length 1.

http://www.ensembl.org/

Examples

ensembl_version

Chicken annotation data

Description

Chicken (Gallus gallus) annotations based on genome assembly GALGAL5 from Ensembl.

Usage

galgal5

Format

An object of class tbl_df (inherits from tbl, data.frame) with 34332 rows and 9 columns.

Details

Variables:

  • ensgene

  • entrez

  • symbol

  • chr

  • start

  • end

  • strand

  • biotype

  • description

http://ensembl.org/gallus_gallus

Examples

head(galgal5)

Chicken transcripts to genes

Description

Lookup table for converting Chicken (Gallus gallus) Ensembl transcript IDs to gene IDs based on genome assembly GALGAL5 from Ensembl.

Usage

galgal5_tx2gene

Format

An object of class tbl_df (inherits from tbl, data.frame) with 72689 rows and 2 columns.

Details

Variables:

  • enstxp

  • ensgene

http://ensembl.org/gallus_gallus

Examples

head(galgal5_tx2gene)

Human annotation data

Description

Human (Homo sapiens) annotations based on genome assembly GRCH37 from Ensembl.

Usage

grch37

Format

An object of class tbl_df (inherits from tbl, data.frame) with 66978 rows and 9 columns.

Details

Variables:

  • ensgene

  • entrez

  • symbol

  • chr

  • start

  • end

  • strand

  • biotype

  • description

http://ensembl.org/homo_sapiens

Examples

head(grch37)

Human transcripts to genes

Description

Lookup table for converting Human (Homo sapiens) Ensembl transcript IDs to gene IDs based on genome assembly GRCH37 from Ensembl.

Usage

grch37_tx2gene

Format

An object of class tbl_df (inherits from tbl, data.frame) with 215170 rows and 2 columns.

Details

Variables:

  • enstxp

  • ensgene

http://ensembl.org/homo_sapiens

Examples

head(grch37_tx2gene)

Human annotation data

Description

Human (Homo sapiens) annotations based on genome assembly GRCH38 from Ensembl.

Usage

grch38

Format

An object of class tbl_df (inherits from tbl, data.frame) with 91673 rows and 9 columns.

Details

Variables:

  • ensgene

  • entrez

  • symbol

  • chr

  • start

  • end

  • strand

  • biotype

  • description

http://ensembl.org/homo_sapiens

Examples

head(grch38)

Human transcripts to genes

Description

Lookup table for converting Human (Homo sapiens) Ensembl transcript IDs to gene IDs based on genome assembly GRCH38 from Ensembl.

Usage

grch38_tx2gene

Format

An object of class tbl_df (inherits from tbl, data.frame) with 412044 rows and 2 columns.

Details

Variables:

  • enstxp

  • ensgene

http://ensembl.org/homo_sapiens

Examples

head(grch38_tx2gene)

Mouse annotation data

Description

Mouse (Mus musculus) annotations based on genome assembly GRCM38 from Ensembl.

Usage

grcm38

Format

An object of class tbl_df (inherits from tbl, data.frame) with 78630 rows and 9 columns.

Details

Variables:

  • ensgene

  • entrez

  • symbol

  • chr

  • start

  • end

  • strand

  • biotype

  • description

http://ensembl.org/mus_musculus

Examples

head(grcm38)

Mouse transcripts to genes

Description

Lookup table for converting Mouse (Mus musculus) Ensembl transcript IDs to gene IDs based on genome assembly GRCM38 from Ensembl.

Usage

grcm38_tx2gene

Format

An object of class tbl_df (inherits from tbl, data.frame) with 278369 rows and 2 columns.

Details

Variables:

  • enstxp

  • ensgene

http://ensembl.org/mus_musculus

Examples

head(grcm38_tx2gene)

Macaque annotation data

Description

Macaque (Macaca mulatta) annotations based on genome assembly MMUL801 from Ensembl.

Usage

mmul801

Format

An object of class tbl_df (inherits from tbl, data.frame) with 36086 rows and 9 columns.

Details

Variables:

  • ensgene

  • entrez

  • symbol

  • chr

  • start

  • end

  • strand

  • biotype

  • description

http://ensembl.org/macaca_mulatta

Examples

head(mmul801)

Macaque transcripts to genes

Description

Lookup table for converting Macaque (Macaca mulatta) Ensembl transcript IDs to gene IDs based on genome assembly MMUL801 from Ensembl.

Usage

mmul801_tx2gene

Format

An object of class tbl_df (inherits from tbl, data.frame) with 64228 rows and 2 columns.

Details

Variables:

  • enstxp

  • ensgene

http://ensembl.org/macaca_mulatta

Examples

head(mmul801_tx2gene)

Rat annotation data

Description

Rat (Rattus norvegicus) annotations based on genome assembly RNOR6 from Ensembl.

Usage

rnor6

Format

An object of class tbl_df (inherits from tbl, data.frame) with 57961 rows and 9 columns.

Details

Variables:

  • ensgene

  • entrez

  • symbol

  • chr

  • start

  • end

  • strand

  • biotype

  • description

http://ensembl.org/rattus_norvegicus

Examples

head(rnor6)

Rat transcripts to genes

Description

Lookup table for converting Rat (Rattus norvegicus) Ensembl transcript IDs to gene IDs based on genome assembly RNOR6 from Ensembl.

Usage

rnor6_tx2gene

Format

An object of class tbl_df (inherits from tbl, data.frame) with 95472 rows and 2 columns.

Details

Variables:

  • enstxp

  • ensgene

http://ensembl.org/rattus_norvegicus

Examples

head(rnor6_tx2gene)

Pig annotation data

Description

Pig (Sus scrofa) annotations based on genome assembly SSCROFA from Ensembl.

Usage

sscrofa

Format

An object of class tbl_df (inherits from tbl, data.frame) with 35819 rows and 9 columns.

Details

Variables:

  • ensgene

  • entrez

  • symbol

  • chr

  • start

  • end

  • strand

  • biotype

  • description

http://ensembl.org/sus_scrofa

Examples

head(sscrofa)

Pig transcripts to genes

Description

Lookup table for converting Pig (Sus scrofa) Ensembl transcript IDs to gene IDs based on genome assembly SSCROFA from Ensembl.

Usage

sscrofa_tx2gene

Format

An object of class tbl_df (inherits from tbl, data.frame) with 60440 rows and 2 columns.

Details

Variables:

  • enstxp

  • ensgene

http://ensembl.org/sus_scrofa

Examples

head(sscrofa_tx2gene)

Roundworm annotation data

Description

Roundworm (Caenorhabditis elegans) annotations based on genome assembly WBCEL235 from Ensembl.

Usage

wbcel235

Format

An object of class tbl_df (inherits from tbl, data.frame) with 49077 rows and 9 columns.

Details

Variables:

  • ensgene

  • entrez

  • symbol

  • chr

  • start

  • end

  • strand

  • biotype

  • description

http://ensembl.org/caenorhabditis_elegans

Examples

head(wbcel235)

Roundworm transcripts to genes

Description

Lookup table for converting Roundworm (Caenorhabditis elegans) Ensembl transcript IDs to gene IDs based on genome assembly WBCEL235 from Ensembl.

Usage

wbcel235_tx2gene

Format

An object of class tbl_df (inherits from tbl, data.frame) with 60000 rows and 2 columns.

Details

Variables:

  • enstxp

  • ensgene

http://ensembl.org/caenorhabditis_elegans

Examples

head(wbcel235_tx2gene)