| Title: | Ensembl Annotation Tables |
|---|---|
| Description: | Provides tables for converting and annotating Ensembl Gene IDs. |
| Authors: | Stephen Turner [aut, cre], Michael J. Steinbaugh [ctb], Aaron Wolen [ctb] |
| Maintainer: | Stephen Turner <[email protected]> |
| License: | GPL-3 |
| Version: | 0.2.0 |
| Built: | 2026-06-08 08:03:06 UTC |
| Source: | https://github.com/stephenturner/annotables |
Provides tables for converting and annotating Ensembl Gene IDs.
Maintainer: Stephen Turner [email protected]
Other contributors:
Michael J. Steinbaugh [email protected] [contributor]
Aaron Wolen [email protected] [contributor]
Useful links:
Report bugs at https://github.com/stephenturner/annotables/issues
Fruitfly (Drosophila melanogaster) annotations based on genome assembly BDGP6 from Ensembl.
bdgp6bdgp6
An object of class tbl_df (inherits from tbl, data.frame) with 26383 rows and 9 columns.
Variables:
ensgene
entrez
symbol
chr
start
end
strand
biotype
description
http://ensembl.org/drosophila_melanogaster
head(bdgp6)head(bdgp6)
Lookup table for converting Fruitfly (Drosophila melanogaster) Ensembl transcript IDs to gene IDs based on genome assembly BDGP6 from Ensembl.
bdgp6_tx2genebdgp6_tx2gene
An object of class tbl_df (inherits from tbl, data.frame) with 41600 rows and 2 columns.
Variables:
enstxp
ensgene
http://ensembl.org/drosophila_melanogaster
head(bdgp6_tx2gene)head(bdgp6_tx2gene)
Gene annotation table for Canis lupus familiaris (dog) from Ensembl.
cfamiliariscfamiliaris
A data frame with gene annotation columns.
Variables:
ensgene
entrez
symbol
chr
start
end
strand
biotype
description
Ensembl
http://ensembl.org/canis_lupus familiaris
head(cfamiliaris)head(cfamiliaris)
Transcript-to-gene mapping for Canis lupus familiaris (dog) from Ensembl.
cfamiliaris_tx2genecfamiliaris_tx2gene
A data frame with transcript and gene columns.
Ensembl
Gene annotation table for Danio rerio (zebrafish) from Ensembl.
dreriodrerio
A data frame with gene annotation columns.
Variables:
ensgene
entrez
symbol
chr
start
end
strand
biotype
description
Ensembl
http://ensembl.org/danio_rerio
head(drerio)head(drerio)
Transcript-to-gene mapping for Danio rerio (zebrafish) from Ensembl.
drerio_tx2genedrerio_tx2gene
A data frame with transcript and gene columns.
Ensembl
Ensembl version used for build
ensembl_versionensembl_version
An object of class character of length 1.
ensembl_versionensembl_version
Chicken (Gallus gallus) annotations based on genome assembly GALGAL5 from Ensembl.
galgal5galgal5
An object of class tbl_df (inherits from tbl, data.frame) with 34332 rows and 9 columns.
Variables:
ensgene
entrez
symbol
chr
start
end
strand
biotype
description
http://ensembl.org/gallus_gallus
head(galgal5)head(galgal5)
Lookup table for converting Chicken (Gallus gallus) Ensembl transcript IDs to gene IDs based on genome assembly GALGAL5 from Ensembl.
galgal5_tx2genegalgal5_tx2gene
An object of class tbl_df (inherits from tbl, data.frame) with 72689 rows and 2 columns.
Variables:
enstxp
ensgene
http://ensembl.org/gallus_gallus
head(galgal5_tx2gene)head(galgal5_tx2gene)
Human (Homo sapiens) annotations based on genome assembly GRCH37 from Ensembl.
grch37grch37
An object of class tbl_df (inherits from tbl, data.frame) with 66978 rows and 9 columns.
Variables:
ensgene
entrez
symbol
chr
start
end
strand
biotype
description
http://ensembl.org/homo_sapiens
head(grch37)head(grch37)
Lookup table for converting Human (Homo sapiens) Ensembl transcript IDs to gene IDs based on genome assembly GRCH37 from Ensembl.
grch37_tx2genegrch37_tx2gene
An object of class tbl_df (inherits from tbl, data.frame) with 215170 rows and 2 columns.
Variables:
enstxp
ensgene
http://ensembl.org/homo_sapiens
head(grch37_tx2gene)head(grch37_tx2gene)
Human (Homo sapiens) annotations based on genome assembly GRCH38 from Ensembl.
grch38grch38
An object of class tbl_df (inherits from tbl, data.frame) with 91673 rows and 9 columns.
Variables:
ensgene
entrez
symbol
chr
start
end
strand
biotype
description
http://ensembl.org/homo_sapiens
head(grch38)head(grch38)
Lookup table for converting Human (Homo sapiens) Ensembl transcript IDs to gene IDs based on genome assembly GRCH38 from Ensembl.
grch38_tx2genegrch38_tx2gene
An object of class tbl_df (inherits from tbl, data.frame) with 412044 rows and 2 columns.
Variables:
enstxp
ensgene
http://ensembl.org/homo_sapiens
head(grch38_tx2gene)head(grch38_tx2gene)
Mouse (Mus musculus) annotations based on genome assembly GRCM38 from Ensembl.
grcm38grcm38
An object of class tbl_df (inherits from tbl, data.frame) with 78630 rows and 9 columns.
Variables:
ensgene
entrez
symbol
chr
start
end
strand
biotype
description
http://ensembl.org/mus_musculus
head(grcm38)head(grcm38)
Lookup table for converting Mouse (Mus musculus) Ensembl transcript IDs to gene IDs based on genome assembly GRCM38 from Ensembl.
grcm38_tx2genegrcm38_tx2gene
An object of class tbl_df (inherits from tbl, data.frame) with 278369 rows and 2 columns.
Variables:
enstxp
ensgene
http://ensembl.org/mus_musculus
head(grcm38_tx2gene)head(grcm38_tx2gene)
Macaque (Macaca mulatta) annotations based on genome assembly MMUL801 from Ensembl.
mmul801mmul801
An object of class tbl_df (inherits from tbl, data.frame) with 36086 rows and 9 columns.
Variables:
ensgene
entrez
symbol
chr
start
end
strand
biotype
description
http://ensembl.org/macaca_mulatta
head(mmul801)head(mmul801)
Lookup table for converting Macaque (Macaca mulatta) Ensembl transcript IDs to gene IDs based on genome assembly MMUL801 from Ensembl.
mmul801_tx2genemmul801_tx2gene
An object of class tbl_df (inherits from tbl, data.frame) with 64228 rows and 2 columns.
Variables:
enstxp
ensgene
http://ensembl.org/macaca_mulatta
head(mmul801_tx2gene)head(mmul801_tx2gene)
Rat (Rattus norvegicus) annotations based on genome assembly RNOR6 from Ensembl.
rnor6rnor6
An object of class tbl_df (inherits from tbl, data.frame) with 57961 rows and 9 columns.
Variables:
ensgene
entrez
symbol
chr
start
end
strand
biotype
description
http://ensembl.org/rattus_norvegicus
head(rnor6)head(rnor6)
Lookup table for converting Rat (Rattus norvegicus) Ensembl transcript IDs to gene IDs based on genome assembly RNOR6 from Ensembl.
rnor6_tx2genernor6_tx2gene
An object of class tbl_df (inherits from tbl, data.frame) with 95472 rows and 2 columns.
Variables:
enstxp
ensgene
http://ensembl.org/rattus_norvegicus
head(rnor6_tx2gene)head(rnor6_tx2gene)
Pig (Sus scrofa) annotations based on genome assembly SSCROFA from Ensembl.
sscrofasscrofa
An object of class tbl_df (inherits from tbl, data.frame) with 35819 rows and 9 columns.
Variables:
ensgene
entrez
symbol
chr
start
end
strand
biotype
description
head(sscrofa)head(sscrofa)
Lookup table for converting Pig (Sus scrofa) Ensembl transcript IDs to gene IDs based on genome assembly SSCROFA from Ensembl.
sscrofa_tx2genesscrofa_tx2gene
An object of class tbl_df (inherits from tbl, data.frame) with 60440 rows and 2 columns.
Variables:
enstxp
ensgene
head(sscrofa_tx2gene)head(sscrofa_tx2gene)
Roundworm (Caenorhabditis elegans) annotations based on genome assembly WBCEL235 from Ensembl.
wbcel235wbcel235
An object of class tbl_df (inherits from tbl, data.frame) with 49077 rows and 9 columns.
Variables:
ensgene
entrez
symbol
chr
start
end
strand
biotype
description
http://ensembl.org/caenorhabditis_elegans
head(wbcel235)head(wbcel235)
Lookup table for converting Roundworm (Caenorhabditis elegans) Ensembl transcript IDs to gene IDs based on genome assembly WBCEL235 from Ensembl.
wbcel235_tx2genewbcel235_tx2gene
An object of class tbl_df (inherits from tbl, data.frame) with 60000 rows and 2 columns.
Variables:
enstxp
ensgene
http://ensembl.org/caenorhabditis_elegans
head(wbcel235_tx2gene)head(wbcel235_tx2gene)